@@ -1,5 +1,4 @@
 import os
-import functools
 import logging
 from typing import List, Optional, Tuple, Dict
 
@@ -122,7 +121,8 @@ auth = jupyterhub.services.auth.HubAuth(
 
 
 async def get_current_user(request: Request) -> User:
-    cookie = request.cookies.get(auth.cookie_name)
+    # cookie = request.cookies.get(auth.cookie_name)
+    cookie = None  # TODO: jupyterhub 2.0 compat
     token = request.headers.get(auth.auth_header_name)
 
     if cookie:
@@ -146,7 +146,6 @@ async def get_current_user(request: Request) -> User:
 # Kubernetes backend configuration
 
 
-@functools.lru_cache
 def get_k8s_api() -> Tuple[kubernetes.client.CoreV1Api, kubernetes.client.BatchV1Api]:
     kubernetes.config.load_config()
 
